@@ -27,17 +27,17 @@ class CustomFormatter(logging.Formatter):
 
     log_levels = {
         'DEBUG': 'DEBUG',
-        'INFO': 'INFO',
-        'WARNING': 'WARN',
+        'INFO': 'INFO ',
+        'WARNING': 'WARN ',
         'ERROR': 'ERROR'
     }
 
     def __init__(self, color: bool = False):
         self.color = color
         if color:
-            fmt = '%(log_color)s[%(log_level)5s]' + colorama.Style.RESET_ALL + ' %(message)s'
+            fmt = f'%(log_color)s[%(log_level)s]{colorama.Style.RESET_ALL} %(message)s'
         else:
-            fmt = '[%(log_level)5s] %(message)s'
+            fmt = '[%(log_level)s] %(message)s'
         super().__init__(fmt=fmt)
 
     def format(self, record: logging.LogRecord) -> str:
@@ -63,51 +63,122 @@ logger.addHandler(file_handler)
 
 # homeman
 class HomeManException(Exception):
+    '''homeman exception'''
     pass
 
 
+def path_exists(path: str):
+    if os.path.islink(path):
+        raise HomeManException(f'occur link: {path}')
+    return os.path.exists(path)
+
+
+def path_remove(path: str, clear: bool = False):
+    if os.path.islink(path):
+        raise HomeManException(f'occur link: {path}')
+    elif os.path.isfile(path):
+        os.remove(path)
+    elif os.path.isdir(path):
+        shutil.rmtree(path)
+    elif os.path.exists(path):
+        raise HomeManException(f'cannot remove: {path}')
+    if clear:
+        os.makedirs(path)
+        os.removedirs(path)
+
+
+def path_make_space(path: str):
+    try:
+        os.makedirs(path)
+    except:
+        raise HomeManException(f'cannot make space for: {path}')
+    else:
+        os.rmdir(path)
+
+
+def path_move(path1: str, path2: str):
+    shutil.move(path1, path2)
+
+
+def path_copy(path1: str, path2: str):
+    if os.path.islink(path1):
+        raise HomeManException(f'occur link: {path1}')
+    if os.path.isfile(path1):
+        shutil.copy(path1, path2)
+    elif os.path.isdir(path1):
+        shutil.copytree(path1, path2)
+    else:
+        raise HomeManException(f'cannot copy: {path1}')
+
+
 class HomeMan:
-    def __init__(self):
-        self.lock_file = os.path.join(tempfile.gettempdir(), 'homeman.lock')
-        self.usr_home = os.path.expanduser('~')
-        self.man_home = os.getenv('MAN_HOME', os.path.join(self.usr_home, '.manhome'))
-        if not os.path.isdir(self.man_home):
-            os.makedirs(self.man_home)
-        self.man_json = os.path.join(self.man_home, 'homeman.json')
+    '''homeman operations'''
 
     def __enter__(self):
+        '''prepare'''
+        self.usr_home = os.path.expanduser('~')
+        self.man_home = os.getenv('MAN_HOME', os.path.join(self.usr_home, '.manhome'))
+
+        # check man_home
+        if self.man_home != os.path.realpath(self.man_home):
+            raise HomeManException(f'home directory is not a real path: {self.man_home}')
+        if not os.path.isdir(self.man_home):
+            try:
+                os.makedirs(self.man_home)
+            except:
+                raise HomeManException(f'cannot create home directory: {self.man_home}')
+        
+        # check man_json
+        self.man_json = os.path.join(self.man_home, 'homeman.json')
+        if not os.path.isfile(self.man_json):
+            with open(self.man_json, 'w') as f:
+                f.write('{}')
+
+        # avoid repeatly run this scripts
+        self.lock_file = os.path.join(tempfile.gettempdir(), 'homeman.lock')
         try:
+            # create the lock file
             with open(self.lock_file, 'x'):
                 pass
         except:
             raise HomeManException('acquire lock failed, another script is running')
         else:
             logger.debug('acquire lock')
-        
-        if not os.path.isfile(self.man_json):
-            with open(self.man_json, 'w') as f:
-                f.write('{}')
+
+        # load man_json
         with open(self.man_json, 'r') as f:
             self.data: Dict = json.load(f)
             logger.debug('load data')
         return self
     
-    def __mark_changed(self):
+    def __mark_data_changed(self):
+        '''mark the data, and indicate that data need save when exit'''
         self.data['homeman_changed'] = True
     
     def __exit__(self, t, e, tb):
+        '''post handle'''
         if e is None:
             if 'homeman_changed' in self.data.keys():
+                # delete the mark
                 del self.data['homeman_changed']
+                # tidy the data and delete the empty node
                 self.__tidy_data()
+                # save the data
                 with open(self.man_json, 'w') as f:
                     json.dump(self.data, f, indent=2)
                     logger.debug('save data')
+        
+        # delete the lock file
         os.remove(self.lock_file)
         logger.debug('release lock')
 
     def get_route(self, path: str) -> str:
+        '''transfor path to route'''
+
+        # get absolute path
         path = os.path.abspath(path)
+
+        # extract route from path
         if path == self.man_home or path == self.usr_home:
             route = ''
         elif path.startswith(self.man_home + os.path.sep):
@@ -116,40 +187,55 @@ class HomeMan:
             route = path[len(self.usr_home):]
         else:
             raise HomeManException(f'path illegal: {path}')
+        
+        # check the route
         if 'homeman' in route:
             raise HomeManException(f'route illegal: {route}')
         logger.debug('route: %s', route)
         return route
 
     def get_data(self, route: str, force: bool = False) -> Union[Dict, None]:
+        '''get corresponding data by route, if force is true, create empty data if not exists'''
+
+        # assign root data and make through...
         cur_data: Dict = self.data
         for name in route.split(os.path.sep)[1:]:
             if 'homeman' in cur_data.keys():
+                # cannot make through if 'homeman' exists
                 return
             if name not in cur_data.keys():
                 if force:
                     cur_data[name] = {}
                 else:
                     return
+            # make through
             cur_data: Dict = cur_data[name]
-        logger.debug('data: %s', cur_data)
         return cur_data
 
-    def __scan_data(self, d: Dict) -> List[Dict[str, str]]:
-        if 'homeman' in d.keys():
-            logger.debug('scan: %s', d)
-            return [d]
+    def __scan_data(self, data: Dict, tag: Union[str, None] = None) -> List[Dict]:
+        '''scan some data that contains 'homeman' key'''
+
+        if 'homeman' in data.keys():
+            if tag is None:
+                return [data]
+            elif 'tags' not in data.keys():
+                return []
+            elif tag in data['tags']:
+                return [data]
+            else:
+                return []
         else:
             d_list = []
-            for key in d.keys():
-                d_list += self.__scan_data(d[key])
+            for key in data.keys():
+                d_list += self.__scan_data(data[key])
             return d_list
 
     def __tidy_data(self):
+        '''tidy data from root data'''
         self.__do_tidy_data(self.data)
-        logger.debug('tidy data')
 
     def __do_tidy_data(self, d: Dict[str, Dict]) -> bool:
+        '''tidy data recursively, and return true if current data is empty'''
         flag = True
         empty_keys = []
         for key in d.keys():
@@ -168,73 +254,110 @@ class HomeMan:
             del d[key]
         return flag
     
-    def add(self, route: str, meta: Dict[str, str]):
+    def add(self, route: str, meta: Dict):
+        '''add a route into home'''
+
         logger.debug('========< add >========')
         if route == '':
             raise HomeManException('cannot add home itself')
-        data = self.get_data(route, force=True)
+        data = self.get_data(route, True)
         if data is None or len(data.keys()) != 0:
             raise HomeManException(f'conflict occur: {route}')
+        
+        # 'homeman' mark this data is a special data
         data['homeman'] = route
+
+        # assign meta
         for key in meta.keys():
+            if key == 'auto':
+                # 'auto' is a special key, indicate auto sync
+                auto: List[str] = meta['auto']
+                new_auto: List[str] = []
+                # check each item in 'auto'
+                for auto_route in auto:
+                    auto_data = self.get_data(auto_route)
+                    if auto_data is None or 'homeman' not in auto_data.keys():
+                        # not a special data
+                        continue
+                    
+                    # 'auto' is paired
+                    if 'auto' not in auto_data.keys():
+                        auto_data['auto'] = []
+                    auto_data['auto'].append(route)
+
+                    new_auto.append(auto_route)
+
+                if len(new_auto) != 0:
+                    data['auto'] = new_auto
+
             data[key] = meta[key]
+
         logger.info('add: %s', route)
-        self.__mark_changed()
+        self.__mark_data_changed()
+
+        # try to fill
         try:
             if 'url' in meta.keys():
+                # this is a remote source
                 self.__pull(data, True)
             else:
+                # this is a local source
                 self.__sync(data, True)
         except HomeManException as e:
             logger.warning(e)
 
-    def remove(self, route: str):
+    def remove(self, route: str, tag: Union[str, None] = None):
+        '''remove a route, may contains multi special route'''
+
         logger.debug('========< remove >========')
         data = self.get_data(route)
         if data is None:
             logger.debug('route not exists: %s', route)
             return
-        for homeman_data in self.__scan_data(data):
+
+        for homeman_data in self.__scan_data(data, tag):
             try:
                 self.__remove(homeman_data)
             except HomeManException as e:
                 logger.warning(e)
-    
-    def __remove(self, data: Dict[str, str]):
+
+    def __remove(self, data: Dict):
+        # restore first
         self.__restore(data)
-        self.__mark_changed()
+
         route = data['homeman']
+        # remove inside path
         man_path = self.man_home + route
-        if os.path.isfile(man_path):
-            os.remove(man_path)
-        elif os.path.isdir(man_path):
-            shutil.rmtree(man_path)
-        elif os.path.exists(man_path):
-            raise HomeManException(f'cannot remove: {man_path}')
-        os.makedirs(man_path)
-        os.removedirs(man_path)
+        path_remove(man_path, True)
+        # clear 'auto' if present
+        if 'auto' in data.keys():
+            for auto_route in data['auto']:
+                auto_route['auto'].remove(route)
         data.clear()
-        self.__mark_changed()
+        self.__mark_data_changed()
         logger.info('remove: %s', route)
 
-    def pull(self, route: str, force: bool):
+    def pull(self, route: str, force: bool = False, tag: Union[str, None] = None):
+        '''pull remote resource'''
+
         logger.debug('========< pull >========')
         data = self.get_data(route)
         if data is None:
             logger.debug('route not exists: %s', route)
             return
-        for homeman_data in self.__scan_data(data):
+
+        for homeman_data in self.__scan_data(data, tag):
             try:
                 self.__pull(homeman_data, force)
             except HomeManException as e:
                 logger.warning(e)
     
-    def __pull(self, data: Dict[str, str], force: bool):
+    def __pull(self, data: Dict, force: bool = False):
         if 'url' not in data.keys():
             return
         route = data['homeman']
         man_path = self.man_home + route
-        if not force and os.path.exists(man_path):
+        if not force and path_exists(man_path):
             return
         url = data['url']
         with tempfile.TemporaryDirectory() as tempdir:
@@ -277,162 +400,157 @@ class HomeMan:
                             t.extractall(temp_node)
                     except:
                         raise HomeManException(f'cannot extract tar from url: {url}')
-            if os.path.isfile(man_path):
-                os.remove(man_path)
-            elif os.path.isdir(man_path):
-                shutil.rmtree(man_path)
-            elif os.path.exists(man_path):
-                raise HomeManException(f'cannot remove: {man_path}')
-            os.makedirs(man_path)
-            os.rmdir(man_path)
-            shutil.move(temp_node, man_path)
+            path_remove(man_path, False)
+            path_make_space(man_path)
+            path_move(temp_node, man_path)
             data['mode'] = bin(os.stat(man_path).st_mode)
-            self.__mark_changed()
+            self.__mark_data_changed()
             logger.info('pull: %s', route)
             self.__sync(data, False)
+            self.__auto_sync(data, [route])
+
+    def sync(self, route: str, reverse: bool = False, tag: Union[str, None] = None):
+        '''keep sync between two home'''
 
-    def sync(self, route: str, reverse: bool):
         logger.debug('========< sync >========')
         data = self.get_data(route)
         if data is None:
             logger.debug('route not exists: %s', route)
             return
-        for homeman_data in self.__scan_data(data):
+
+        for homeman_data in self.__scan_data(data, tag):
             try:
                 self.__sync(homeman_data, reverse)
             except HomeManException as e:
                 logger.warning(e)
     
-    def __sync(self, data: Dict[str, str], reverse: bool):
-        usr_path = self.usr_home + data['homeman']
-        man_path = self.man_home + data['homeman']
+    def __sync(self, data: Dict, reverse: bool = False):
+        route = data['homeman']
+        usr_path = self.usr_home + route
+        man_path = self.man_home + route
         if reverse:
             if not os.path.exists(usr_path):
                 raise HomeManException(f'not exists: {usr_path}')
             self.__backup(data, False)
-            if os.path.isfile(man_path):
-                os.remove(man_path)
-            elif os.path.isdir(man_path):
-                shutil.rmtree(man_path)
-            elif os.path.exists(man_path):
-                raise HomeManException(f'cannot remove: {man_path}')
-            os.makedirs(man_path)
-            os.rmdir(man_path)
-            if os.path.isfile(usr_path):
-                shutil.copy(usr_path, man_path)
-            elif os.path.isdir(usr_path):
-                shutil.copytree(usr_path, man_path)
-            else:
-                raise HomeManException(f'cannot copy: {usr_path}')
+            path_remove(man_path, False)
+            path_make_space(man_path)
+            path_copy(usr_path, man_path)
             data['mode'] = bin(os.stat(man_path).st_mode)
-            self.__mark_changed()
-            logger.info('sync reversely: %s', data['homeman'])
+            self.__mark_data_changed()
+            logger.info('sync reversely: %s', route)
+            self.__auto_sync(data, [route])
         else:
             if not os.path.exists(man_path):
                 raise HomeManException(f'not exists: {man_path}')
             self.__backup(data, False)
-            if os.path.isfile(usr_path):
-                os.remove(usr_path)
-            elif os.path.isdir(usr_path):
-                shutil.rmtree(usr_path)
-            elif os.path.exists(usr_path):
-                raise HomeManException(f'cannot remove: {usr_path}')
-            os.makedirs(usr_path)
-            os.rmdir(usr_path)
-            if os.path.isfile(man_path):
-                shutil.copy(man_path, usr_path)
-            elif os.path.isdir(man_path):
-                shutil.copytree(man_path, usr_path)
-            else:
-                raise HomeManException(f'cannot copy: {man_path}')
+            path_remove(usr_path)
+            path_make_space(usr_path)
+            path_copy(man_path, usr_path)
             os.chmod(usr_path, int(data['mode'], 2))
-            logger.info('sync: %s', data['homeman'])
+            logger.info('sync: %s', route)
+
+    def __auto_sync(self, data: Dict, global_routes: List[str]):
+        if 'auto' not in data.keys():
+            return
+        route = data['homeman']
+        man_path = self.man_home + route
+        for slave_route in data['auto']:
+            if slave_route in global_routes:
+                continue
+            global_routes.append(slave_route)
+            slave_data = self.get_data(slave_route)
+            if slave_data is None or 'homeman' not in slave_data.keys():
+                continue
+            slave_man_path = self.man_home + slave_data['homeman']
+            path_remove(slave_man_path, False)
+            path_make_space(slave_man_path)
+            path_copy(man_path, slave_man_path)
+            slave_data['mode'] = bin(os.stat(slave_man_path).st_mode)
+            self.__mark_data_changed()
+            logger.info('auto sync: %s', slave_route)
+            self.__sync(slave_data, False)
+            self.__auto_sync(slave_data, global_routes)
+
+    def backup(self, route: str, force: bool = False, tag: Union[str, None] = None):
+        '''backup outside node'''
 
-    def backup(self, route: str, force: bool):
         logger.debug('========< backup >========')
         data = self.get_data(route)
         if data is None:
             logger.debug('route not exists: %s', route)
             return
-        for homeman_data in self.__scan_data(data):
+
+        for homeman_data in self.__scan_data(data, tag):
             try:
                 self.__backup(homeman_data, force)
             except HomeManException as e:
                 logger.warning(e)
     
-    def __backup(self, data: Dict[str, str], force: bool):
+    def __backup(self, data: Dict, force: bool = False):
         route = data['homeman']
         usr_path = self.usr_home + route
         usr_path_bak = usr_path + '.homeman.bak'
         usr_path_bak2 = usr_path_bak + '.empty'
-        if not force and (os.path.exists(usr_path_bak) or os.path.exists(usr_path_bak2)):
+        if not force and (path_exists(usr_path_bak) or path_exists(usr_path_bak2)):
             return
-        if os.path.isfile(usr_path_bak):
-            os.remove(usr_path_bak)
-        elif os.path.isdir(usr_path_bak):
-            shutil.rmtree(usr_path_bak)
-        elif os.path.isfile(usr_path_bak2):
-            os.remove(usr_path_bak2)
-        if os.path.isfile(usr_path):
-            shutil.copy(usr_path, usr_path_bak)
-        elif os.path.isdir(usr_path):
-            shutil.copytree(usr_path, usr_path_bak)
+        if path_exists(usr_path):
+            path_remove(usr_path_bak)
+            path_remove(usr_path_bak2)
+            path_copy(usr_path, usr_path_bak)
         else:
-            os.makedirs(usr_path)
-            os.rmdir(usr_path)
+            path_make_space(usr_path)
             with open(usr_path_bak2, 'w'):
                 pass
         logger.info('backup: %s', route)
 
-    def restore(self, route: str):
+    def restore(self, route: str, tag: Union[str, None] = None):
+        '''restore outside node'''
+
         logger.debug('========< restore >========')
         data = self.get_data(route)
         if data is None:
             logger.debug('route not exists: %s', route)
             return
-        for homeman_data in self.__scan_data(data):
+
+        for homeman_data in self.__scan_data(data, tag):
             try:
                 self.__restore(homeman_data)
             except HomeManException as e:
                 logger.warning(e)
     
-    def __restore(self, data: Dict[str, str]):
+    def __restore(self, data: Dict):
         route = data['homeman']
         usr_path = self.usr_home + route
         usr_path_bak = usr_path + '.homeman.bak'
         usr_path_bak2 = usr_path_bak + '.empty'
-        if not os.path.exists(usr_path_bak) and not os.path.exists(usr_path_bak2):
+        if not path_exists(usr_path_bak) and not path_exists(usr_path_bak2):
             return
-        if os.path.isfile(usr_path):
-            os.remove(usr_path)
-        elif os.path.isdir(usr_path):
-            shutil.rmtree(usr_path)
-        if os.path.exists(usr_path_bak):
-            shutil.move(usr_path_bak, usr_path)
+        path_remove(usr_path)
+        if path_exists(usr_path_bak):
+            path_move(usr_path_bak, usr_path)
         else:
-            os.remove(usr_path_bak2)
-            os.mkdir(usr_path)
-            os.removedirs(usr_path)
+            path_remove(usr_path_bak2, True)
         logger.info('restore: %s', route)
 
-    def check(self, route: str, show_diff: bool, formatter: str = 'none'):
+    def check(self, route: str, show_diff: bool, tag: Union[str, None] = None):
         logger.debug('========< check >========')
         data = self.get_data(route)
         if data is None:
             logger.debug('route not exists: %s', route)
             return
-        for homeman_data in self.__scan_data(data):
+
+        for homeman_data in self.__scan_data(data, tag):
             try:
-                self.__check(homeman_data, show_diff, formatter)
+                self.__check(homeman_data, show_diff)
             except HomeManException as e:
                 logger.warning(e)
     
-    def __check(self, data: Dict[str, str], show_diff: bool, formatter: str = 'none'):
+    def __check(self, data: Dict, show_diff: bool):
         route = data['homeman']
         usr_path = self.usr_home + route
         usr_path_bak = usr_path + '.homeman.bak'
         usr_path_bak2 = usr_path_bak + '.empty'
-        if not os.path.exists(usr_path_bak) and not os.path.exists(usr_path_bak2):
+        if not path_exists(usr_path_bak) and not path_exists(usr_path_bak2):
             logger.warning('not backup: %s', route)
         else:
             man_path = self.man_home + route
@@ -472,13 +590,17 @@ class HomeMan:
                                 print('is dir inside')
                             else:
                                 with open(usr_f, 'r') as uf, open(man_f, 'r') as mf:
-                                    if formatter == 'json':
-                                        ulines = json.dumps(
-                                            json.load(uf), indent=2
-                                        ).splitlines(keepends=True)
-                                        mlines = json.dumps(
-                                            json.load(mf), indent=2
-                                        ).splitlines(keepends=True)
+                                    if 'formatter' in data.keys():
+                                        formatter = data['formatter']
+                                        if formatter == 'json':
+                                            ulines = json.dumps(
+                                                json.load(uf), indent=2
+                                            ).splitlines(keepends=True)
+                                            mlines = json.dumps(
+                                                json.load(mf), indent=2
+                                            ).splitlines(keepends=True)
+                                        else:
+                                            raise HomeManException(f'unknown formatter: {formatter}')
                                     else:
                                         ulines = uf.readlines()
                                         mlines = mf.readlines()
@@ -504,7 +626,7 @@ class HomeMan:
 def main():
     homeman_parse = argparse.ArgumentParser(
         prog='homeman',
-        description='this is a tool to manage your files or directories in user home, base on symbol links.'
+        description='a small management tool to keep files synchronized between user home and your special home directory.'
     )
 
     homeman_parse.add_argument(
@@ -546,6 +668,18 @@ def main():
         '-b', '--branch', type=str,
         help='special the branch name when resource type is git'
     )
+    command_add.add_argument(
+        '-f', '--formatter', type=str, choices=['none', 'json'], default='none',
+        help='formatter the content'
+    )
+    command_add.add_argument(
+        '-a', '--auto', nargs='*', default=[],
+        help='auto sync'
+    )
+    command_add.add_argument(
+        '-t', '--tags', nargs='*', default=[],
+        help='filter node'
+    )
 
     # pull
     command_pull = homeman_commands.add_parser(
@@ -559,6 +693,10 @@ def main():
         '-f', '--force', action='store_true',
         help='set the console log level to DEBUG'
     )
+    command_add.add_argument(
+        '-t', '--tag', type=str, default=None,
+        help='filter node'
+    )
 
     # remove
     command_remove = homeman_commands.add_parser(
@@ -568,6 +706,10 @@ def main():
         'path', type=str,
         help='the location of resource'
     )
+    command_remove.add_argument(
+        '-t', '--tag', type=str, default=None,
+        help='filter node'
+    )
 
     # sync
     command_sync = homeman_commands.add_parser(
@@ -581,6 +723,10 @@ def main():
         '-v', '--reverse', action='store_true',
         help='set the console log level to DEBUG'
     )
+    command_sync.add_argument(
+        '-t', '--tag', type=str, default=None,
+        help='filter node'
+    )
 
     # backup
     command_backup = homeman_commands.add_parser(
@@ -594,6 +740,10 @@ def main():
         '-f', '--force', action='store_true',
         help='set the console log level to DEBUG'
     )
+    command_backup.add_argument(
+        '-t', '--tag', type=str, default=None,
+        help='filter node'
+    )
 
     # restore
     command_restore = homeman_commands.add_parser(
@@ -603,6 +753,10 @@ def main():
         'path', type=str,
         help='the location of resource'
     )
+    command_restore.add_argument(
+        '-t', '--tag', type=str, default=None,
+        help='filter node'
+    )
 
     # check
     command_check = homeman_commands.add_parser(
@@ -617,8 +771,8 @@ def main():
         help='show diff'
     )
     command_check.add_argument(
-        '-f', '--formatter', type=str, choices=['none', 'json'], default='none',
-        help='show diff'
+        '-t', '--tag', type=str, default=None,
+        help='filter node'
     )
 
     args = homeman_parse.parse_args()
@@ -643,19 +797,27 @@ def main():
                     meta['url'] = args.url
                     if args.branch:
                         meta['branch'] = args.branch
+                if args.formatter != 'none':
+                    meta['formatter'] = args.formatter
+                if len(args.auto) != 0:
+                    for i, e in enumerate(args.auto):
+                        args.auto[i] = hm.get_route(e)
+                    meta['auto'] = args.auto
+                if len(args.tags) != 0:
+                    meta['tags'] = args.tags
                 hm.add(route, meta)
             elif args.command == 'remove':
-                hm.remove(route)
+                hm.remove(route, args.tag)
             elif args.command == 'pull':
-                hm.pull(route, args.force)
+                hm.pull(route, args.force, args.tag)
             elif args.command == 'sync':
-                hm.sync(route, args.reverse)
+                hm.sync(route, args.reverse, args.tag)
             elif args.command == 'backup':
-                hm.backup(route, args.force)
+                hm.backup(route, args.force, args.tag)
             elif args.command == 'restore':
-                hm.restore(route)
+                hm.restore(route, args.tag)
             elif args.command == 'check':
-                hm.check(route, args.show, args.formatter)
+                hm.check(route, args.show, args.tag)
     except HomeManException as e:
         logger.error(e)
         return 1
